library(survey)
library(tidyverse)
library(srvyr)
library(gtsummary)
library(patchwork)
library(ggeffects)
library(readxl)
library(writexl)
library(rms)
library(ggplot2)
library(ggthemes)
library(RColorBrewer)
library(GGally)
library(predROC)

#palette using black
cbbPalette <- c("#000000", "#E69F00", "#56B4E9",  "#490092", "#CC79A7")

#Import CLUSTer and NHMS dataset (excel)
CLUSTer_NHMS <- read_excel("Desktop/Data_S1.xlsx")

CLUSTer_NHMS$Data <- as.factor(CLUSTer_NHMS$Data)
CLUSTer_NHMS$Age_CAT <- as.factor(CLUSTer_NHMS$Age_CAT)
CLUSTer_NHMS$Disease <- as.factor(CLUSTer_NHMS$Disease)
CLUSTer_NHMS$Disease <- factor(CLUSTer_NHMS$Disease, levels = c("DM","Undiagnosed_DM","IFG"))

Disease <- c(
  `DM` = "Known T2DM",
  `Undiagnosed_DM` = "Undiagnosed T2DM",
  `IFG` = "Impaired fasting glucose")

Age_pyramid <- CLUSTer_NHMS %>%
  ggplot(aes(x = Age_CAT, fill = Data,
             ifelse(test = Data == "NHMS",
                    yes = -Proportion, no = Proportion))) + 
  geom_bar(stat = "identity") +
  scale_y_continuous(labels = abs, limits = max(CLUSTer_NHMS$Proportion) * c(-1,1)) +
  labs(x = "Age group", y = "Weighted Prevalence (%)", fill = "Data set") + 
  coord_flip() +
  facet_wrap(~ Disease, labeller = as_labeller(Disease)) +
  theme(axis.text.x = element_text(angle = 90, hjust = 1)) +
  scale_fill_grey(name = "Data set", labels = c("CLUSTer (2013-2015)","NHMS 2015"))+
  cowplot::theme_cowplot()

Age_pyramid +
  theme(strip.background = element_rect(fill = "white"),
        strip.text = element_text(size = 15))

ggsave("Figure1.png",
       plot = Age_pyramid,
       width = 3000,
       height = 1500,
       units = "px",
       dpi = 300,
       bg = "white")

#Import Raw data for weighted descriptive (n=14144)
Raw_data <- read_xlsx("Desktop/Data_S2.xlsx")
Raw_data$DM_char <- as.character(Raw_data$DM)

#Complex design setup
options(survey.lonely.psu = "adjust")
options(survey.adjust.domain.lonely = TRUE)

design.CLUSTer <- Raw_data %>%
  as_survey_design(ids = No, weights = School_weight, strata = NULL)

#Weighted descriptive analysis

svy_descriptive <- design.CLUSTer %>% 
  tbl_svysummary(
    include = c(Age,Sex,Ethnic,Edu_level,marital,Fam_His_DM_CAT,Fruit,Vege,Fruit_Vege_adequate,sleep_hr_day_cleaned,
                sleep_hr_end_cleaned,Total_Mets,sit_min, smoke_ever, alcohol, waist_cleaned, Waist_CAT,
                Total_Depression, Total_Anxiety, Total_Stress,DM, IFG),
    type = all_dichotomous() ~"categorical",
    statistic = list(all_continuous()  ~ "{mean} ({sd})",
                     all_categorical() ~ "{n_unweighted} ({p}%)"),
    digits = all_continuous() ~ 2, label = list(Edu_level~"Education",marital~"Marital status",waist_cleaned~"Waist circumference (cm)", Waist_CAT~"Abdominal obese",
                                                sit_min~"Duration of sitting (minutes)",Total_Mets~"Physical Activity (Mets/day in a week)",
                                                smoke_ever~"Smoking status",alcohol~"Alcohol consumption",Fruit~"Fruit consumption (servings/day)",Vege~"Vege consumption (servings/day)",
                                                Total_Depression~"Depression score",Total_Anxiety~"Anxiety score",Total_Stress~"Stress score",
                                                DM~"T2DM status", IFG~"Impaired Fasting glucose", sleep_hr_day_cleaned~"Sleep hours (weekday)",
                                                sleep_hr_end_cleaned~"Sleep hours (weekend)",Fruit_Vege_adequate~"Fruit and Vegetable consumption"),
    missing = "no",
    missing_text = "Missing") %>%
  modify_header(label = "**Variables**") %>%
  modify_caption("Weighted descriptive statistics") %>%
  bold_labels() %>%
  add_ci()

svy_descriptive_2 <- design.CLUSTer %>% 
  tbl_svysummary(by = Sex, percent = "column",
    include = c(Age,Ethnic,Edu_level,marital,Fam_His_DM_CAT,Fruit,Vege,Fruit_Vege_adequate,sleep_hr_day_cleaned,
                sleep_hr_end_cleaned,Total_Mets,sit_min, smoke_ever, alcohol, waist_cleaned, Waist_CAT,
                Total_Depression, Total_Anxiety, Total_Stress,DM_char, IFG),
    type = all_categorical() ~"categorical",
    statistic = list(all_continuous()  ~ "{mean} ({sd})",
                     all_categorical() ~ "{n_unweighted} ({p}%)"),
    digits = all_continuous() ~ 2, label = list(Edu_level~"Education",marital~"Marital status",waist_cleaned~"Waist circumference (cm)", Waist_CAT~"Abdominal obese",
                                                sit_min~"Duration of sitting (minutes)",Total_Mets~"Physical Activity (METs/day in a week)", Fam_His_DM_CAT~"Family history of T2DM",
                                                smoke_ever~"Smoking status",alcohol~"Alcohol consumption",Fruit~"Fruit consumption (servings/day)",Vege~"Vege consumption (servings/day)",
                                                Total_Depression~"Depression score",Total_Anxiety~"Anxiety score",Total_Stress~"Stress score",
                                                DM_char~"T2DM status", IFG~"Impaired Fasting glucose", sleep_hr_day_cleaned~"Sleep hours (weekday)",
                                                sleep_hr_end_cleaned~"Sleep hours (weekend)",Fruit_Vege_adequate~"Fruit and Vegetable consumption"),
    missing = "no",
    missing_text = "Missing") %>%
  modify_header(label = "**Variables**") %>%
  modify_caption("Weighted descriptive statistics") %>%
  bold_labels() %>%
  add_overall() %>%
  add_n(statistic = "{N_nonmiss_unweighted}") %>%
  add_ci()

svy_descriptive_2 %>%
  as_flex_table() %>%
  flextable::save_as_docx(path = "Weighted_Descriptive_stat.docx")

temp_state_school <- Raw_data[,c("No","School_weight","States","School")]
temp_state_school$States <- as.factor(temp_state_school$States)
temp_state_school$School <- as.factor(temp_state_school$School)

#Import Raw data 2 (n=11412) # Reduced from participants with incomplete dataset
Raw_data2 <- read_excel("Desktop/Data_S3.xlsx")
Raw_data2 <- Raw_data2[,-c(2:4)]
Raw_data2 <- inner_join(Raw_data2, temp_state_school,
                                 by = "No")
Raw_data2 <- Raw_data2[,c(1,42:44,2:41)]

#Relevel factors
Raw_data2$IFG <- as.numeric(Raw_data2$IFG)
Raw_data2$DM <- as.numeric(Raw_data2$DM)

Raw_data2[sapply(Raw_data2, is.character)] <- lapply(Raw_data2[sapply(Raw_data2, is.character)], 
                                       as.factor)
Raw_data2 <- Raw_data2 %>%
  mutate(Sex = fct_relevel(Sex, "Male","Female"),
         Ethnic = fct_relevel(Ethnic, "Malay","Chinese","Indian","Other races"),
         EducationLevel2 = fct_relevel(EducationLevel2, "Diploma and below","Degree","Master and above"),
         MaritalStatus2 = fct_relevel(MaritalStatus2, "Single", "Married", "Divorced/Widowed"),
         PA_CAT = fct_relevel(PA_CAT, "Low","Moderate","High"),
         Fruit_Vege_adequate = fct_relevel(Fruit_Vege_adequate, "Inadequate","Adequate"),
         )

#Complex design setup
design.CLUSTer_Sub <- Raw_data2 %>%
  as_survey_design(ids = No, weights = School_weight, strata = NULL)

design.CLUSTer_Male <- Raw_data2 %>%
  filter(Sex == "Male") %>%
  as_survey_design(ids = No, weights = School_weight, strata = NULL)

design.CLUSTer_Female <- Raw_data2 %>%
  filter(Sex == "Female") %>%
  as_survey_design(ids = No, weights = School_weight, strata = NULL)


#Univariables analysis on risk/protective factors associated with DM

svy_uv_dm <- design.CLUSTer_Sub %>%
  tbl_uvregression(
    method = survey::svyglm,
    y = DM,
    method.args = list(family = quasibinomial),
    include = c(Age,Sex,Ethnic,EducationLevel2,MaritalStatus2,Fam_His_DM_CAT,
                GDM_CAT,WaistCircumference,Sit_min,PA_CAT,Smokingstatus,
                Alcoholconsumption,SleepDuration,Fruit_Vege_adequate,
                Total_Depression,Total_Anxiety,Total_Stress),
    exponentiate = TRUE,
    pvalue_fun = ~style_pvalue(.x, digits = 2),
    label = list(Age ~ "Age", Sex ~ "Sex", Ethnic ~ "Ethnicity", EducationLevel2~"Education level",
                 MaritalStatus2~"Marital status",Fam_His_DM_CAT~"Family history of T2DM",
                 GDM_CAT~"History of gestational DM", WaistCircumference~"Waist circumference (cm)",
                 Sit_min~"Sit duration(minutes)",PA_CAT~"Physical activity", Smokingstatus~"Smoking",
                 Alcoholconsumption~"Alcohol consumption", SleepDuration~"Sleep duration (hours/day)",
                 Fruit_Vege_adequate~"Fruits & Vegetables servings/day", Total_Depression~"Depression",
                 Total_Anxiety~"Anxiety",Total_Stress~"Stress")) %>%
  add_significance_stars(hide_ci = F, hide_p = F, hide_se = T) %>%
  add_global_p()

#glmdmModel1-2 (Saturated model to reduced model)

svyglmdmModel1 <- svyglm(DM~Age+Sex+Ethnic+EducationLevel2+MaritalStatus2+Fam_His_DM_CAT+WaistCircumference+Sit_min
                         +PA_CAT+Smokingstatus+Alcoholconsumption+SleepDuration+Fruit_Vege_adequate+Total_Depression
                         +Total_Anxiety+Total_Stress, family = quasibinomial, design = design.CLUSTer_Sub)

tbl_regression(svyglmdmModel1,
               exponentiate = TRUE,
               list(Age ~ "Age", Sex ~ "Sex", Ethnic ~ "Ethnicity",EducationLevel2~"Education Level", MaritalStatus2~"Marital Status",
                    Fam_His_DM_CAT~"Family History of T2DM",WaistCircumference~"Waist circumference (cm)",Sit_min~"Sit duration(minutes)",
                    PA_CAT~"Physical activity", Smokingstatus~"Smoking",Alcoholconsumption~"Alcohol consumption",
                    SleepDuration~"Sleep duration (hours/day)", Fruit_Vege_adequate~"Fruits & Vegetables servings/day", Total_Depression~"Depression",
                    Total_Anxiety~"Anxiety",Total_Stress~"Stress")) %>%
  bold_labels() %>%
  add_vif()


svyglmdmModel2 <- svyglm(DM~Age+Sex+Ethnic+EducationLevel2+MaritalStatus2+Fam_His_DM_CAT+WaistCircumference+Sit_min
                         +SleepDuration+Total_Depression+Total_Anxiety+Total_Stress, family = quasibinomial, design = design.CLUSTer_Sub)

tbl_regression(svyglmdmModel2,
               exponentiate = TRUE,
               list(Age ~ "Age", Sex ~ "Sex", Ethnic ~ "Ethnicity",EducationLevel2~"Education Level", MaritalStatus2~"Marital Status",
                    Fam_His_DM_CAT~"Family History of T2DM",WaistCircumference~"Waist circumference (cm)",Sit_min~"Sit duration(minutes)",
                    SleepDuration~"Sleep duration (hours/day)", Total_Depression~"Depression",
                    Total_Anxiety~"Anxiety",Total_Stress~"Stress")) %>%
  bold_labels() %>%
  add_vif() %>%
  add_global_p()

lrtest(svyglmdmModel1,svyglmdmModel2)

#Reduced model + interaction

svyglmdmModel3 <- svyglm(DM~Age+Ethnic+Fam_His_DM_CAT+WaistCircumference+
                           WaistCircumference*Age+WaistCircumference*Fam_His_DM_CAT
                         ,family = quasibinomial, design = design.CLUSTer_Sub)
summary(svyglmdmModel3)

tbl_regression(svyglmdmModel3,
               exponentiate = T,
               list(Age ~ "Age",Ethnic ~ "Ethnicity",Fam_His_DM_CAT~"Family History of T2DM",WaistCircumference~"Waist circumference (cm)")) %>%
  bold_labels() %>%
  add_global_p()

#Multivariable regression plot (T2DM)

P1 <- plot(ggpredict(svyglmdmModel3, terms = c("WaistCircumference[all]","Age[25,35,45,55]"))) + 
  labs(x= "Waist circumference (cm)", y="Predicted T2DM (%)", title = "A") +
  theme(text = element_text(size = 13)) +
  geom_vline(xintercept = 100, linetype="dotted", 
             color = "black", size=1.0)

P1 <- P1 + scale_colour_manual(values = cbbPalette)+ scale_fill_manual(values = cbbPalette)

P2 <- plot(ggpredict(svyglmdmModel3, terms = c("WaistCircumference[all]","Fam_His_DM_CAT"))) +
  labs(x= "Waist circumference (cm)", y="", title = "B", colour = "Family history of T2DM") +
  theme(text = element_text(size = 13)) +
  geom_vline(xintercept = 100, linetype="dotted",
             color = "black", size=1.0)

P2 <- P2 + scale_colour_manual(values = cbbPalette)+ scale_fill_manual(values = cbbPalette)

Figure2 <- P1+P2

ggsave("Figure2.png",
       plot = Figure2,
       width = 3000,
       height = 1500,
       units = "px",
       dpi = 300,
       bg = "white")

#Stratify by gender (male)
svyglmdmModel3_male <- svyglm(DM~Age+Ethnic+Fam_His_DM_CAT+WaistCircumference+
                           WaistCircumference*Age+WaistCircumference*Fam_His_DM_CAT
                         ,family = quasibinomial, design = design.CLUSTer_Male)

P1_m <- plot(ggpredict(svyglmdmModel3_male, terms = c("WaistCircumference[all]","Age[25,35,45,55]"))) + 
  labs(x= "Waist circumference (cm)", y="Predicted T2DM (%)", title = "B") +
  theme(text = element_text(size = 13)) +
  geom_vline(xintercept = 100, linetype="dotted", 
             color = "red", size=1.0)

P2_m <- plot(ggpredict(svyglmdmModel3_male, terms = c("WaistCircumference[all]","Fam_His_DM_CAT"))) +
  labs(x= "Waist circumference (cm)", y="Predicted T2DM (%)", title = "E") +
  theme(text = element_text(size = 13))+
  geom_vline(xintercept = 100, linetype="dotted",
             color = "red", size=1.0)

#Stratify by gender (female)
svyglmdmModel3_female <- svyglm(DM~Age+Ethnic+Fam_His_DM_CAT+WaistCircumference+
                                WaistCircumference*Age+WaistCircumference*Fam_His_DM_CAT
                              ,family = quasibinomial, design = design.CLUSTer_Female)

P1_f <- plot(ggpredict(svyglmdmModel3_female, terms = c("WaistCircumference[all]","Age[25,35,45,55]"))) + 
  labs(x= "Waist circumference (cm)", y="Predicted T2DM (%)", title = "C") +
  theme(text = element_text(size = 13)) +
  geom_vline(xintercept = 100, linetype="dotted", 
             color = "red", size=1.0)

P2_f <- plot(ggpredict(svyglmdmModel3_female, terms = c("WaistCircumference[all]","Fam_His_DM_CAT"))) +
  labs(x= "Waist circumference (cm)", y="Predicted T2DM (%)", title = "F") +
  theme(text = element_text(size = 13))+
  geom_vline(xintercept = 100, linetype="dotted",
             color = "red", size=1.0)


#Combine plots (Overall, male, female)
P1+P1_m+P1_f+P2+P2_m+P2_f

#Univariables analysis on risk/protective factors associated with IFG

svy_uv_IFG <- design.CLUSTer_Sub %>%
  tbl_uvregression(
    method = survey::svyglm,
    y = IFG,
    method.args = list(family = quasibinomial),
    include = c(Age,Sex,Ethnic,EducationLevel2,MaritalStatus2,Fam_His_DM_CAT,
                GDM_CAT,WaistCircumference,Sit_min,PA_CAT,Smokingstatus,
                Alcoholconsumption,SleepDuration,Fruit_Vege_adequate,
                Total_Depression,Total_Anxiety,Total_Stress),
    exponentiate = TRUE,    
    pvalue_fun = ~style_pvalue(.x, digits = 2),
    label = list(Age ~ "Age", Sex ~ "Sex", Ethnic ~ "Ethnicity", EducationLevel2~"Education level",
                 MaritalStatus2~"Marital status",Fam_His_DM_CAT~"Family history of T2DM",
                 GDM_CAT~"History of gestational DM", WaistCircumference~"Waist circumference (cm)",
                 Sit_min~"Sit duration(minutes)",PA_CAT~"Physical activity", Smokingstatus~"Smoking",
                 Alcoholconsumption~"Alcohol consumption", SleepDuration~"Sleep duration (hours/day)",
                 Fruit_Vege_adequate~"Fruits & Vegetables servings/day", Total_Depression~"Depression",
                 Total_Anxiety~"Anxiety",Total_Stress~"Stress")) %>%
  add_significance_stars(hide_ci = F, hide_p = F, hide_se = T) %>%
  add_global_p()

#Multivariable analysis on lifestyle factors associated with IFG (Saturated model to reduced model)

svyglmIFGModel1 <- svyglm(IFG~Age+Sex+Ethnic+MaritalStatus2+Fam_His_DM_CAT+WaistCircumference
                               +PA_CAT+Fruit_Vege_adequate+SleepDuration+Total_Stress+Smokingstatus+Alcoholconsumption, family = quasibinomial, design = design.CLUSTer_Sub)

tbl_regression(svyglmIFGModel1,
               exponentiate = TRUE) %>%
  bold_labels() %>%
  add_vif() %>%
  add_global_p()

svyglmIFGModel2 <- svyglm(IFG~Age+Ethnic+Fam_His_DM_CAT+WaistCircumference
                               +PA_CAT, family = quasibinomial, design = design.CLUSTer_Sub)

tbl_regression(svyglmIFGModel2,
               exponentiate = TRUE) %>%
  bold_labels() %>%
  add_vif() %>%
  add_global_p()

#Include interaction terms
svyglmIFGModel3<- svyglm(IFG~Age+Ethnic+Fam_His_DM_CAT+WaistCircumference
                                +PA_CAT+Age*WaistCircumference+Ethnic*WaistCircumference
                                +Ethnic*PA_CAT
                                ,family = quasibinomial, design = design.CLUSTer_Sub)

summary(svyglmIFGModel3)

tbl_regression(svyglmIFGModel3,
               exponentiate = TRUE) %>%
  bold_labels()

P3 <- plot(ggpredict(svyglmIFGModel3, terms = c("WaistCircumference[all]","Age[25,35,45,55]"))) + 
  labs(x= "Waist Circumference (cm)", y="Predicted impaired fasting glucose (%)", title = "A") +
  theme(text = element_text(size = 13))

P4 <- plot(ggpredict(svyglmIFGModel3, terms = c("WaistCircumference[all]","Ethnic"))) + 
  labs(x= "Waist Circumference (cm)", y="", title = "B") +
  theme(text = element_text(size = 13))

P5 <- plot(ggpredict(svyglmIFGModel3, terms = c("PA_CAT","Ethnic"))) + 
  labs(x= "Physical activity", y="", title = "C") +
  theme(text = element_text(size = 13)) +
  geom_line()

P3 <- P3 + scale_colour_manual(values = cbbPalette)+ scale_fill_manual(values = cbbPalette)
P4 <- P4 + scale_colour_manual(values = cbbPalette)+ scale_fill_manual(values = cbbPalette)
P5 <- P5 + scale_colour_manual(values = cbbPalette)+ scale_fill_manual(values = cbbPalette)

Figure3 <- P3+P4+P5

ggsave("Figure3.png",
       plot = Figure3,
       width = 3000,
       height = 1500,
       units = "px",
       dpi = 300,
       bg = "white")

#Stratify by gender (male)

svyglmIFGModel3_male<- svyglm(IFG~Age+Ethnic+Fam_His_DM_CAT+WaistCircumference
                              +PA_CAT
                         ,family = quasibinomial, design = design.CLUSTer_Male) #Remove all interaction terms due to errors


P3_m <- plot(ggpredict(svyglmIFGModel3_male, terms = c("WaistCircumference[all]","Age[25,35,45,55]"))) + 
  labs(x= "Waist Circumference (cm)", y="", title = "B") +
  theme(text = element_text(size = 13))

P4_m <- plot(ggpredict(svyglmIFGModel3_male, terms = c("WaistCircumference[all]","Ethnic"))) + 
  labs(x= "Waist Circumference (cm)", y="Predicted impaired fasting glucose (%)", title = "E") +
  theme(text = element_text(size = 13))

P5_m <- plot(ggpredict(svyglmIFGModel3_male, terms = c("PA_CAT","Ethnic"))) + 
  labs(x= "Physical activity", y="", title = "H") +
  theme(text = element_text(size = 13)) +
  geom_line()

#Stratify by gender (female)

svyglmIFGModel3_female<- svyglm(IFG~Age+Ethnic+Fam_His_DM_CAT+WaistCircumference
                                +PA_CAT+Age*WaistCircumference+Ethnic*WaistCircumference
                                +Ethnic*PA_CAT
                                ,family = quasibinomial, design = design.CLUSTer_Female)

P3_f <- plot(ggpredict(svyglmIFGModel3_female, terms = c("WaistCircumference[all]","Age[25,35,45,55]"))) + 
  labs(x= "Waist Circumference (cm)", y="", title = "C") +
  theme(text = element_text(size = 13))

P4_f <- plot(ggpredict(svyglmIFGModel3_female, terms = c("WaistCircumference[all]","Ethnic"))) + 
  labs(x= "Waist Circumference (cm)", y="Predicted impaired fasting glucose (%)", title = "F") +
  theme(text = element_text(size = 13))

P5_f <- plot(ggpredict(svyglmIFGModel3_female, terms = c("PA_CAT","Ethnic"))) + 
  labs(x= "Physical activity", y="", title = "I") +
  theme(text = element_text(size = 13)) +
  geom_line()

#Combine plots (Overall, male, female)
P3+P3_m+P3_f+P4+P4_m+P4_f+P5+P5_m+P5_f

#Ad-hoc analysis (Lifestyle factors associated with waist circumference)

WC_model1 <- svyglm(WaistCircumference~Age+Sex+Ethnic+EducationLevel2+MaritalStatus2+Fam_His_DM_CAT+Sit_min
                    +PA_CAT+Smokingstatus+Alcoholconsumption+SleepDuration+Fruit_Vege_adequate+Total_Depression
                    +Total_Anxiety+Total_Stress, family = gaussian, design = design.CLUSTer_Sub)

summary(WC_model1)     

WC_model2 <- svyglm(WaistCircumference~Age+Sex+Ethnic+MaritalStatus2+Fam_His_DM_CAT
                    +PA_CAT+SleepDuration+
                      +Total_Anxiety, family = gaussian, design = design.CLUSTer_Sub)
summary(WC_model2)

tbl_regression(WC_model2,
               exponentiate = F) %>%
  bold_labels() %>%
  add_vif() %>%
  add_global_p()

#Cross-check with BMI
Raw_data3 <- inner_join(Raw_data2, BMI_data,
                        by = "No")
library(ggpubr)
ggqqplot(Raw_data3$bmi)

#replace NA with median value due to non-normal distribution
Raw_data3 <- Raw_data3 %>% mutate(across(bmi, ~replace_na(., median(., na.rm=TRUE))))

#Complex design setup with an inclusion of bmi
design.CLUSTer_Sub_bmi <- Raw_data3 %>%
  as_survey_design(ids = No, weights = School_weight, strata = NULL)

svyglmdmModel_bmi <- svyglm(DM~Age+Ethnic+Fam_His_DM_CAT+WaistCircumference+
                              WaistCircumference*Age+WaistCircumference*Fam_His_DM_CAT+bmi
                            ,family = quasibinomial, design = design.CLUSTer_Sub_bmi)

svyglmIFGModel3_bmi<- svyglm(IFG~Age+Ethnic+Fam_His_DM_CAT+WaistCircumference
                             +PA_CAT+Age*WaistCircumference+Ethnic*WaistCircumference
                             +Ethnic*PA_CAT+bmi
                             ,family = quasibinomial, design = design.CLUSTer_Sub_bmi)

#Compare models (with and without an inclusion of BMI)
anova(svyglmdmModel3,svyglmdmModel_bmi)
AIC(svyglmdmModel3,svyglmdmModel_bmi)
anova(svyglmIFGModel3,svyglmIFGModel3_bmi)
AIC(svyglmIFGModel3,svyglmIFGModel3_bmi)

#Correlation plots between BMI and Waist circumference
Raw_data3 %>%
  select(WaistCircumference,bmi) %>%
  ggpairs()

